Documentation
¶
Overview ¶
Package stitch is a simple wrapper around the standard libraries gif.GIF type that enables easy combination of multiple source files into a single merged animation. The source files can also be looped multiple times if required.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type File ¶
type File struct {
// contains filtered or unexported fields
}
File represents a single GIF to be added to the final product. The full GIF will be added at least once, but possibly more depending on the arguments supplied to the Create function.
type GIF ¶
type GIF struct {
// contains filtered or unexported fields
}
GIF is a wrapper around a gif.GIF from the standard library.
func Create ¶
Create takes a list of files and a list of loop counts. If the list of loop counts is empty, each file will be added to the final product exactly once. Otherwise, the number of loop counts must equal the number of files, and each file will be added a number of times equal to its loop count.